# -*- coding: utf-8 -*-
"""
Pypelines: pipeline syntax for IPython and Jupyter.
Just run `%load_ext pypelines` to begin using powerful new pipe operators, placeholder syntax, and more.
"""

from . import _version  # noqa: E402
__version__ = _version.get_versions()['version']
